==> realestate-supervise-common-1.1.0-20220222.015921-5-sources.jar: cn/gtmap/realestate/supervise/entity/BaHZrz.java <==
package cn.gtmap.realestate.supervise.entity;

import com.sun.istack.internal.Nullable;

import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;


@Table(
        name = "BA_H_ZRZ"
)
public class BaHZrz implements Serializable {

    private String ywh;

    private int bsm;

    private String ysdm;

    private String bdcdyh;

    private String zddm;

    private String zrzh;

    @Nullable
    private String xmmc;

    @Nullable
    private String jzwmc;

    @Nullable
    private Date jgrq;

    @Nullable
    private String jzwgd;

    private String zzdmj;

    private String zydmj;

    @Nullable
    private String ycjzmj;

    @Nullable
    private String scjzmj;

    private String zcs;

    private String dscs;

    private String dxcs;

    @Nullable
    private String dxsd;

    private String ghyt;

    private String fwjg;

    private int zts;

    @Nullable
    private String jzwjbyt;

    @Nullable
    private String dah;

    @Nullable
    private String bz;

    private String zt;

    private String qxdm;

    private String id;

    private String zrzbh;

    private Date sjgxsj;

    public BaHZrz(){}

    public BaHZrz(BaZrz baZrz, String ywh){
        this.ywh = ywh;
        this.bsm = baZrz.getBsm();
        this.ysdm = baZrz.getYsdm();
        this.bdcdyh = baZrz.getBdcdyh();
        this.zddm = baZrz.getZddm();
        this.zrzh = baZrz.getZrzh();
        this.xmmc = baZrz.getXmmc();
        this.jzwmc = baZrz.getJzwmc();
        this.jgrq = baZrz.getJgrq();
        this.jzwgd = baZrz.getJzwgd();
        this.zzdmj = baZrz.getZzdmj();
        this.zydmj = baZrz.getZydmj();
        this.ycjzmj = baZrz.getYcjzmj();
        this.scjzmj = baZrz.getScjzmj();
        this.zcs = baZrz.getZcs();
        this.dscs = baZrz.getDscs();
        this.dxcs = baZrz.getDxcs();
        this.dxsd = baZrz.getDxsd();
        this.ghyt = baZrz.getGhyt();
        this.fwjg = baZrz.getFwjg();
        this.zts = baZrz.getZts();
        this.dah = baZrz.getDah();
        this.bz = baZrz.getBz();
        this.zt = baZrz.getZt();
        this.qxdm = baZrz.getQxdm();
        this.id = baZrz.getId();
        this.zrzbh = baZrz.getZrzbh();
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public int getBsm() {
        return bsm;
    }

    public void setBsm(int bsm) {
        this.bsm = bsm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getJzwmc() {
        return jzwmc;
    }

    public void setJzwmc(String jzwmc) {
        this.jzwmc = jzwmc;
    }

    public Date getJgrq() {
        return jgrq;
    }

    public void setJgrq(Date jgrq) {
        this.jgrq = jgrq;
    }

    public String getJzwgd() {
        return jzwgd;
    }

    public void setJzwgd(String jzwgd) {
        this.jzwgd = jzwgd;
    }

    public String getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(String zzdmj) {
        this.zzdmj = zzdmj;
    }

    public String getZydmj() {
        return zydmj;
    }

    public void setZydmj(String zydmj) {
        this.zydmj = zydmj;
    }

    public String getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(String ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public String getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(String scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getDscs() {
        return dscs;
    }

    public void setDscs(String dscs) {
        this.dscs = dscs;
    }

    public String getDxcs() {
        return dxcs;
    }

    public void setDxcs(String dxcs) {
        this.dxcs = dxcs;
    }

    public String getDxsd() {
        return dxsd;
    }

    public void setDxsd(String dxsd) {
        this.dxsd = dxsd;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public int getZts() {
        return zts;
    }

    public void setZts(int zts) {
        this.zts = zts;
    }

    public String getJzwjbyt() {
        return jzwjbyt;
    }

    public void setJzwjbyt(String jzwjbyt) {
        this.jzwjbyt = jzwjbyt;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }


    public String getZrzbh() {
        return zrzbh;
    }

    public void setZrzbh(String zrzbh) {
        this.zrzbh = zrzbh;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }
}

==> realestate-supervise-common-1.1.0-20220818.055648-18-sources.jar: cn/gtmap/realestate/supervise/entity/BaHZrz.java <==
package cn.gtmap.realestate.supervise.entity;

import com.sun.istack.internal.Nullable;

import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;


@Table(
        name = "BA_H_ZRZ"
)
public class BaHZrz implements Serializable {

    private String ywh;

    private String bsm;

    private String ysdm;

    private String bdcdyh;

    private String zddm;

    private String zrzh;

    @Nullable
    private String xmmc;

    @Nullable
    private String jzwmc;

    @Nullable
    private Date jgrq;

    @Nullable
    private String jzwgd;

    private String zzdmj;

    private String zydmj;

    @Nullable
    private String ycjzmj;

    @Nullable
    private String scjzmj;

    private String zcs;

    private String dscs;

    private String dxcs;

    @Nullable
    private String dxsd;

    private String ghyt;

    private String fwjg;

    private int zts;

    @Nullable
    private String jzwjbyt;

    @Nullable
    private String dah;

    @Nullable
    private String bz;

    private String zt;

    private String qxdm;

    private String id;

    private String zrzbh;

    private Date sjgxsj;

    public BaHZrz(){}

    public BaHZrz(BaZrz baZrz, String ywh){
        this.ywh = ywh;
        this.bsm = baZrz.getBsm();
        this.ysdm = baZrz.getYsdm();
        this.bdcdyh = baZrz.getBdcdyh();
        this.zddm = baZrz.getZddm();
        this.zrzh = baZrz.getZrzh();
        this.xmmc = baZrz.getXmmc();
        this.jzwmc = baZrz.getJzwmc();
        this.jgrq = baZrz.getJgrq();
        this.jzwgd = baZrz.getJzwgd();
        this.zzdmj = baZrz.getZzdmj();
        this.zydmj = baZrz.getZydmj();
        this.ycjzmj = baZrz.getYcjzmj();
        this.scjzmj = baZrz.getScjzmj();
        this.zcs = baZrz.getZcs();
        this.dscs = baZrz.getDscs();
        this.dxcs = baZrz.getDxcs();
        this.dxsd = baZrz.getDxsd();
        this.ghyt = baZrz.getGhyt();
        this.fwjg = baZrz.getFwjg();
        this.zts = baZrz.getZts();
        this.dah = baZrz.getDah();
        this.bz = baZrz.getBz();
        this.zt = baZrz.getZt();
        this.qxdm = baZrz.getQxdm();
        this.id = baZrz.getId();
        this.zrzbh = baZrz.getZrzbh();
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getBsm() {
        return bsm;
    }

    public void setBsm(String bsm) {
        this.bsm = bsm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getJzwmc() {
        return jzwmc;
    }

    public void setJzwmc(String jzwmc) {
        this.jzwmc = jzwmc;
    }

    public Date getJgrq() {
        return jgrq;
    }

    public void setJgrq(Date jgrq) {
        this.jgrq = jgrq;
    }

    public String getJzwgd() {
        return jzwgd;
    }

    public void setJzwgd(String jzwgd) {
        this.jzwgd = jzwgd;
    }

    public String getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(String zzdmj) {
        this.zzdmj = zzdmj;
    }

    public String getZydmj() {
        return zydmj;
    }

    public void setZydmj(String zydmj) {
        this.zydmj = zydmj;
    }

    public String getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(String ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public String getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(String scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getDscs() {
        return dscs;
    }

    public void setDscs(String dscs) {
        this.dscs = dscs;
    }

    public String getDxcs() {
        return dxcs;
    }

    public void setDxcs(String dxcs) {
        this.dxcs = dxcs;
    }

    public String getDxsd() {
        return dxsd;
    }

    public void setDxsd(String dxsd) {
        this.dxsd = dxsd;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public int getZts() {
        return zts;
    }

    public void setZts(int zts) {
        this.zts = zts;
    }

    public String getJzwjbyt() {
        return jzwjbyt;
    }

    public void setJzwjbyt(String jzwjbyt) {
        this.jzwjbyt = jzwjbyt;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }


    public String getZrzbh() {
        return zrzbh;
    }

    public void setZrzbh(String zrzbh) {
        this.zrzbh = zrzbh;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }
}
